package com.goldenwater.slaj.eme.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eme.mapper.BusiPlanDisclosureMapper;
import com.goldenwater.slaj.eme.domain.BusiPlanDisclosure;
import com.goldenwater.slaj.eme.service.IBusiPlanDisclosureService;

/**
 * 预案信息公开 服务层实现
 */
@Service
public class BusiPlanDisclosureServiceImpl implements IBusiPlanDisclosureService {

    @Autowired
    private BusiPlanDisclosureMapper busiPlanDisclosureMapper;

    @Override
    public BusiPlanDisclosure selectBusiPlanDisclosureByGuid(String guid) {
        return busiPlanDisclosureMapper.selectBusiPlanDisclosureByGuid(guid);
    }

    @Override
    public List<BusiPlanDisclosure> selectBusiPlanDisclosureList(BusiPlanDisclosure busiPlanDisclosure) {
        return busiPlanDisclosureMapper.selectBusiPlanDisclosureList(busiPlanDisclosure);
    }

    @Override
    public int insertBusiPlanDisclosure(BusiPlanDisclosure busiPlanDisclosure) {
        return busiPlanDisclosureMapper.insertBusiPlanDisclosure(busiPlanDisclosure);
    }

    @Override
    public int updateBusiPlanDisclosure(BusiPlanDisclosure busiPlanDisclosure) {
        return busiPlanDisclosureMapper.updateBusiPlanDisclosure(busiPlanDisclosure);
    }

    @Override
    public int deleteBusiPlanDisclosureByGuid(String guid) {
        return busiPlanDisclosureMapper.deleteBusiPlanDisclosureByGuid(guid);
    }

    @Override
    public int deleteBusiPlanDisclosureByGuids(String[] guids) {
        return busiPlanDisclosureMapper.deleteBusiPlanDisclosureByGuids(guids);
    }
}
